<?php
/**
 * Default theme options
 *
 * @package Travel_Gem
 */

if ( ! function_exists( 'travel_gem_get_default_theme_options' ) ) :

	/**
	 * Get default theme options.
	 *
	 * @since 1.0.0
	 *
	 * @return array Default theme options.
	 */
	function travel_gem_get_default_theme_options() {

		$defaults = array();

		// Title tagline.
		$defaults['show_title']   = true;
		$defaults['show_tagline'] = true;

		// Design.
		$defaults['color_scheme'] = 'default';
		$defaults['button_type']  = 'rectangle';

		// Font.
		$font_keys = travel_gem_get_font_family_theme_settings_options();
		if ( ! empty( $font_keys ) ) {
			foreach ( $font_keys as $k => $v ) {
				$defaults[ $k ] = $v['default'];
			}
		}

		// Header.
		$defaults['header_layout']              = 1;
		$defaults['contact_number']             = '9876543210';
		$defaults['contact_email']              = 'demo@example.com';
		$defaults['contact_address']            = esc_html__( 'Kathmandu, Nepal', 'travel-gem-pro' );
		$defaults['quote_button_text']          = esc_html__( 'Book Now', 'travel-gem-pro' );
		$defaults['quote_button_url']           = '#';
		$defaults['enable_sticky_primary_menu'] = false;

		// Header.
		$defaults['custom_header_layout']          = 1;
		$defaults['custom_header_show_title']      = true;
		$defaults['custom_header_show_breadcrumb'] = true;

		// Layout.
		$defaults['site_layout']             = 'fluid';
		$defaults['global_layout']           = 'right-sidebar';
		$defaults['archive_layout']          = 'grid';
		$defaults['archive_image']           = 'large';
		$defaults['archive_image_alignment'] = 'center';
		$defaults['single_image']            = 'large';
		$defaults['single_image_alignment']  = 'center';

		// Blog.
		$defaults['blog_title']     = esc_html__( 'Blog', 'travel-gem-pro' );
		$defaults['excerpt_length'] = 40;
		$defaults['read_more_text'] = esc_html__( 'Read More', 'travel-gem-pro' );

		// Breadcrumb.
		$defaults['breadcrumb_home_text']  = esc_html__( 'Home', 'travel-gem-pro' );
		$defaults['breadcrumb_show_title'] = true;

		// Footer.
		$defaults['copyright_text']  = esc_html__( 'Copyright &copy; {{the-year}} {{the-site-link}}. All rights reserved.', 'travel-gem-pro' );
		$defaults['powered_by_text'] = esc_html__( 'Travel Gem Pro by ', 'travel-gem-pro' ) . '<a target="_blank" href="https://wenthemes.com/">WEN Themes</a>';

		// Pass through filter.
		$defaults = apply_filters( 'travel_gem_filter_default_theme_options', $defaults );
		return $defaults;
	}

endif;
