<?php
/**
 * CSS related hooks.
 *
 * This file contains hook functions which are related to CSS.
 *
 * @package Travel_Gem
 */

if ( ! function_exists( 'travel_gem_trigger_custom_css_action' ) ) :

	/**
	 * Do action theme custom CSS.
	 *
	 * @since 1.0.0
	 */
	function travel_gem_trigger_custom_css_action() {

		/**
		 * Hook - travel_gem_action_theme_custom_css.
		 */
		do_action( 'travel_gem_action_theme_custom_css' );

	}

endif;

add_action( 'wp_head', 'travel_gem_trigger_custom_css_action', 99 );

if ( ! function_exists( 'travel_gem_add_theme_custom_font_css' ) ) :

	/**
	 * Add theme custom font CSS.
	 *
	 * @since 1.0.0
	 */
	function travel_gem_add_theme_custom_font_css() {

		$custom_css = '';

		$font_settings = travel_gem_get_font_family_theme_settings_options();

		$required_fonts = array();

		if ( ! empty( $font_settings ) ) {
			foreach ( $font_settings as $key => $val ) {
				$option_value = travel_gem_get_option( $key );
				if ( ! empty( $option_value ) && $val['default'] !== $option_value ) {
					$required_fonts[ $key ] = $option_value;
				}
			}
		}

		if ( empty( $required_fonts ) ) {

			// We do not need extra CSS.
			return;
		}

		foreach ( $required_fonts as $key => $font ) {

			$family = travel_gem_get_font_family_from_key( $font );

			if ( ! empty( $family ) ) {

				switch ( $key ) {
					case 'font_site_default':
						$custom_css .= 'body{font-family:' . $family . '}' . "\n";
					break;

					case 'font_site_title':
						$custom_css .= '.site-title{font-family:' . $family . '}' . "\n";
					break;

					case 'font_site_tagline':
						$custom_css .= '.site-description{font-family:' . $family . '}' . "\n";
					break;

					case 'font_heading_tags':
						$custom_css .= 'h1,h2,h3,h4,h5,h6{font-family:' . $family . '}' . "\n";
					break;

					case 'font_content_title':
						$custom_css .= '.entry-header .entry-title{font-family:' . $family . '}' . "\n";
					break;

					case 'font_content_body':
						$custom_css .= '#content{font-family:' . $family . '}' . "\n";
					break;

					case 'font_navigation':
						$custom_css .= '.main-navigation ul li a{font-family:' . $family . '}' . "\n";
					break;

					default:
					break;
				}
			}
		}

		// Render style.
		if ( ! empty( $custom_css ) ) {
			echo '<style type="text/css">';
			echo wp_strip_all_tags( $custom_css );
			echo '</style>';
		}

	}

endif;

add_action( 'travel_gem_action_theme_custom_css', 'travel_gem_add_theme_custom_font_css' );
