<?php
/**
 * Latest news widget
 *
 * Widget Name: Travel Gem Latest News
 * Description: Displays latest posts in grid.
 * Author: WEN Themes
 * Author URI: https://wenthemes.com
 *
 * @package Travel_Gem
 */

/**
 * Latest news widget class.
 *
 * @since 1.0.0
 */
class Travel_Gem_Latest_News_Widget extends SiteOrigin_Widget {

	/**
	 * Constructor.
	 *
	 * @since 1.0.0
	 */
	function __construct() {

		parent::__construct(
			'travel-gem-latest-news',
			esc_html__( 'Travel Gem: Latest News', 'travel-gem-pro' ),
			array(
				'description' => esc_html__( 'Displays latest posts in grid.', 'travel-gem-pro' ),
			),
			array(),
			false,
			plugin_dir_path( __FILE__ )
		);
	}

	/**
	 * Get widget form.
	 *
	 * @since 1.0.0
	 *
	 * @return array Widget form.
	 */
	function get_widget_form() {

		return array(
			'title' => array(
				'type'  => 'text',
				'label' => esc_html__( 'Title', 'travel-gem-pro' ),
				),
			'subtitle' => array(
				'type'  => 'text',
				'label' => esc_html__( 'Subtitle', 'travel-gem-pro' ),
				),
			'heading_alignment' => array(
				'label'   => esc_html__( 'Title/subtitle Alignment', 'travel-gem-pro' ),
				'type'    => 'select',
				'default' => 'center',
				'options' => travel_gem_get_heading_alignment_options(),
				),
			'post_category' => array(
				'label'           => esc_html__( 'Select Category:', 'travel-gem-pro' ),
				'type'            => 'taxonomy-dropdown',
				'show_option_all' => esc_html__( 'All Categories', 'travel-gem-pro' ),
				),
			'post_number' => array(
				'label'   => esc_html__( 'Number of Posts', 'travel-gem-pro' ),
				'type'    => 'number',
				'default' => 3,
				),
			'post_column' => array(
				'label'   => esc_html__( 'Number of Columns', 'travel-gem-pro' ),
				'type'    => 'select',
				'default' => 3,
				'options' => travel_gem_get_numbers_dropdown_options( 2, 4 ),
				),
			'featured_image' => array(
				'label'   => esc_html__( 'Featured Image', 'travel-gem-pro' ),
				'type'    => 'select',
				'default' => 'large',
				'options' => travel_gem_get_image_sizes_options( false ),
				),
			'more_text' => array(
				'label'   => esc_html__( 'More Text', 'travel-gem-pro' ),
				'type'    => 'text',
				'default' => esc_html__( 'Know More', 'travel-gem-pro' ),
				),
			'excerpt_length' => array(
				'label'       => esc_html__( 'Excerpt Length', 'travel-gem-pro' ),
				'description' => esc_html__( 'in words', 'travel-gem-pro' ),
				'type'        => 'number',
				'default'     => 15,
				),
			'explore_button_text' => array(
				'label'   => esc_html__( 'Explore Button Text', 'travel-gem-pro' ),
				'type'    => 'text',
				'default' => esc_html__( 'Explore More', 'travel-gem-pro' ),
				),
			'explore_button_url' => array(
				'label'   => esc_html__( 'Explore Button URL', 'travel-gem-pro' ),
				'type'    => 'link',
				'default' => '',
				),
			);
	}

}

siteorigin_widget_register( 'travel-gem-latest-news', __FILE__, 'Travel_Gem_Latest_News_Widget' );
