<?php
/**
 * Team widget
 *
 * Widget Name: Travel Gem Team
 * Description: Displays team block.
 * Author: WEN Themes
 * Author URI: https://wenthemes.com
 *
 * @package Travel_Gem
 */

/**
 * Team widget class.
 *
 * @since 1.0.0
 */
class Travel_Gem_Team_Widget extends SiteOrigin_Widget {

	/**
	 * Constructor.
	 *
	 * @since 1.0.0
	 */
	function __construct() {

		parent::__construct(
			'travel-gem-team',
			esc_html__( 'Travel Gem: Team', 'travel-gem-pro' ),
			array(
				'description' => esc_html__( 'Displays team block.', 'travel-gem-pro' ),
			),
			array(),
			false,
			plugin_dir_path( __FILE__ )
		);
	}

	/**
	 * Get widget form.
	 *
	 * @since 1.0.0
	 *
	 * @return array Widget form.
	 */
	function get_widget_form() {

		return array(
			'title' => array(
				'type'  => 'text',
				'label' => esc_html__( 'Title', 'travel-gem-pro' ),
				),
			'subtitle' => array(
				'type'  => 'text',
				'label' => esc_html__( 'Subtitle', 'travel-gem-pro' ),
				),
			'heading_alignment' => array(
				'label'   => esc_html__( 'Title/subtitle Alignment', 'travel-gem-pro' ),
				'type'    => 'select',
				'default' => 'center',
				'options' => travel_gem_get_heading_alignment_options(),
				),
			'members' => array(
				'type'       => 'repeater',
				'label'      => esc_html__( 'Members', 'travel-gem-pro' ),
				'item_name'  => esc_html__( 'Member', 'travel-gem-pro' ),
				'item_label' => array(
					'selector'     => "[id*='members-member_name']",
					'update_event' => 'change',
					'value_method' => 'val',
					),
				'fields' => array(
					'member_name' => array(
						'type'  => 'text',
						'label' => esc_html__( 'Name', 'travel-gem-pro' ),
						),
					'member_position' => array(
						'type'  => 'text',
						'label' => esc_html__( 'Position', 'travel-gem-pro' ),
						),
					'member_picture' => array(
						'type'     => 'media',
						'label'    => esc_html__( 'Icon', 'travel-gem-pro' ),
						'fallback' => true,
						'library'  => 'image',
						),
					'member_url' => array(
						'type'  => 'link',
						'label' => esc_html__( 'URL', 'travel-gem-pro' ),
						),
					'social_links' => array(
						'type'       => 'repeater',
						'label'      => esc_html__( 'Social Links', 'travel-gem-pro' ),
						'item_name'  => esc_html__( 'Link', 'travel-gem-pro' ),
						'item_label' => array(
							'selector'     => "[id*='social_links-social_url']",
							'update_event' => 'change',
							'value_method' => 'val',
							),
						'fields' => array(
							'social_icon' => array(
								'type'  => 'icon',
								'label' => esc_html__( 'Icon', 'travel-gem-pro' ),
								),
							'social_url' => array(
								'type'        => 'text',
								'label'       => esc_html__( 'URL', 'travel-gem-pro' ),
								'placeholder' => esc_html__( 'Enter full URL.', 'travel-gem-pro' ),
								),
							),
						),
					),
				),
			'settings' => array(
				'label'  => esc_html__( 'Settings', 'travel-gem-pro' ),
				'type'   => 'section',
				'hide'   => false,
				'fields' => array(
					'post_column' => array(
						'label'   => esc_html__( 'Number of Columns', 'travel-gem-pro' ),
						'type'    => 'select',
						'default' => 4,
						'options' => travel_gem_get_numbers_dropdown_options( 3, 4 ),
						),
					'new_window' => array(
						'label'   => esc_html__( 'Open URL in new window', 'travel-gem-pro' ),
						'type'    => 'checkbox',
						'default' => false,
						),
					),
				),
			);
	}

}

siteorigin_widget_register( 'travel-gem-team', __FILE__, 'Travel_Gem_Team_Widget' );
