<?php
/**
 * Testimonials widget
 *
 * Widget Name: Travel Gem Testimonials
 * Description: Displays testimonials as carousel.
 * Author: WEN Themes
 * Author URI: https://wenthemes.com
 *
 * @package Travel_Gem
 */

/**
 * Testimonials widget class.
 *
 * @since 1.0.0
 */
class Travel_Gem_Testimonials_Widget extends SiteOrigin_Widget {

	/**
	 * Constructor.
	 *
	 * @since 1.0.0
	 */
	function __construct() {

		parent::__construct(
			'travel-gem-testimonials',
			esc_html__( 'Travel Gem: Testimonials', 'travel-gem-pro' ),
			array(
				'description' => esc_html__( 'Displays testimonials as carousel.', 'travel-gem-pro' ),
			),
			array(),
			false,
			plugin_dir_path( __FILE__ )
		);
	}

	/**
	 * Get widget form.
	 *
	 * @since 1.0.0
	 *
	 * @return array Widget form.
	 */
	function get_widget_form() {

		return array(
			'title' => array(
				'type'  => 'text',
				'label' => esc_html__( 'Title', 'travel-gem-pro' ),
				),
			'subtitle' => array(
				'type'  => 'text',
				'label' => esc_html__( 'Subtitle', 'travel-gem-pro' ),
				),
			'heading_alignment' => array(
				'label'   => esc_html__( 'Title/subtitle Alignment', 'travel-gem-pro' ),
				'type'    => 'select',
				'default' => 'center',
				'options' => travel_gem_get_heading_alignment_options(),
				),
			'testimonials' => array(
				'type'       => 'repeater',
				'label'      => esc_html__( 'Testimonials', 'travel-gem-pro' ),
				'item_name'  => esc_html__( 'Testimonial', 'travel-gem-pro' ),
				'item_label' => array(
					'selector'     => "[id*='testimonials-testimonial_name']",
					'update_event' => 'change',
					'value_method' => 'val',
					),
				'fields' => array(
					'testimonial_name' => array(
						'type'        => 'text',
						'label'       => esc_html__( 'Name', 'travel-gem-pro' ),
						'description' => esc_html__( 'The author of the testimonial.', 'travel-gem-pro' ),
						),
					'testimonial_location' => array(
						'type'        => 'text',
						'label'       => esc_html__( 'Location', 'travel-gem-pro' ),
						'description' => esc_html__( 'Their location or company name.', 'travel-gem-pro' ),
						),
					'testimonial_message' => array(
						'type'  => 'textarea',
						'label' => esc_html__( 'Message', 'travel-gem-pro' ),
						),
					'testimonial_image' => array(
						'type'     => 'media',
						'label'    => esc_html__( 'Image', 'travel-gem-pro' ),
						'library'  => 'image',
						'choose'   => esc_html__( 'Choose Image', 'travel-gem-pro' ),
						'update'   => esc_html__( 'Set Image', 'travel-gem-pro' ),
						'fallback' => true,
						),
					),
				),
			'settings' => array(
				'label'  => esc_html__( 'Settings', 'travel-gem-pro' ),
				'type'   => 'section',
				'hide'   => true,
				'fields' => array(
					'enable_autoplay' => array(
						'label'   => esc_html__( 'Enable Autoplay', 'travel-gem-pro' ),
						'type'    => 'checkbox',
						'default' => false,
						),
					'transition_delay' => array(
						'label'       => esc_html__( 'Transition Delay', 'travel-gem-pro' ),
						'description' => esc_html__( 'in seconds', 'travel-gem-pro' ),
						'type'        => 'number',
						'default'     => 3,
						),
					),
				),
			);
	}

	/**
	 * Initialize.
	 *
	 * @since 1.0.0
	 */
	function initialize() {
		$min = defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG ? '' : '.min';

		$this->register_frontend_scripts(
			array(
				array(
					'jquery-slick',
					get_template_directory_uri() . '/third-party/slick/slick' . $min . '.js',
					array( 'jquery' ),
					'1.5.9',
					),
				)
		);

		$this->register_frontend_styles(
			array(
				array(
					'jquery-slick',
					get_template_directory_uri() . '/third-party/slick/slick' . $min . '.css',
					array(),
					'1.5.9',
					),
				)
		);
	}
}

siteorigin_widget_register( 'travel-gem-testimonials', __FILE__, 'Travel_Gem_Testimonials_Widget' );
